<?php if ( ! defined( 'ABSPATH' ) ) { die; } // Cannot access pages directly.

// -----------------------------------------
// Custom Widgets                    -
// -----------------------------------------
function spalab_custom_widgets() {
  $custom_widgets = array();
  $widgets = is_array( cs_get_option( 'widgetarea-custom' ) ) ? cs_get_option( 'widgetarea-custom' ) : array();
  $widgets = array_filter($widgets);

  if( isset( $widgets ) ):
    foreach ( $widgets as $widget ) :
      $id = mb_convert_case($widget['widgetarea-custom-name'], MB_CASE_LOWER, "UTF-8");
      $id = str_replace(" ", "-", $id);
      $custom_widgets[$id] = $widget['widgetarea-custom-name'];
    endforeach;
  endif;

  return $custom_widgets;
}

// -----------------------------------------
// Layer Sliders
// -----------------------------------------
function spalab_layersliders() {
  $layerslider = array(  esc_html__('Select a slider','spalab') );

  if( class_exists( 'LS_Sliders' ) ) {

    $sliders = LS_Sliders::find(array('limit' => 50));

    if(!empty($sliders)) {
      foreach($sliders as $key => $item){
        $layerslider[ $item['id'] ] = $item['name'];
      }
    }
  }

  return $layerslider;
}

// -----------------------------------------
// Revolution Sliders
// -----------------------------------------
function spalab_revolutionsliders() {
  $revolutionslider = array( '' => esc_html__('Select a slider','spalab') );

  if(class_exists( 'RevSlider' )) {
    $sld = new RevSliderSlider();
    $sliders = $sld->getArrSliders();
    if(!empty($sliders)){
      foreach($sliders as $key => $item) {
        $revolutionslider[$item->getAlias()] = $item->getTitle();
      }
    }    
  }

  return $revolutionslider;  
}

// -----------------------------------------
// Meta Layout Section
// -----------------------------------------
$meta_layout_section =array(
  'name'  => 'layout_section',
  'title' => esc_html__('Layout', 'spalab'),
  'icon'  => 'fa fa-columns',
  'fields' =>  array(
    array(
      'id'  => 'layout',
      'type' => 'image_select',
      'title' => esc_html__('Page Layout', 'spalab' ),
      'options'      => array(
          'content-full-width'   => SPALAB_THEME_URI . '/cs-framework-override/images/without-sidebar.png',
          'with-left-sidebar'    => SPALAB_THEME_URI . '/cs-framework-override/images/left-sidebar.png',
          'with-right-sidebar'   => SPALAB_THEME_URI . '/cs-framework-override/images/right-sidebar.png',
          'with-both-sidebar'    => SPALAB_THEME_URI . '/cs-framework-override/images/both-sidebar.png',
          'fullwidth'            => SPALAB_THEME_URI . '/cs-framework-override/images/fullwidth.png',
      ),
      'default'      => 'content-full-width',
	  'info'		 => esc_html__('Layout "fullwidth" only apply for portfolio template.', 'spalab'),
      'attributes'   => array( 'data-depend-id' => 'page-layout' )
    ),
    array(
      'id'        => 'show-standard-sidebar-left',
      'type'      => 'switcher',
      'title'     => esc_html__('Show Standard Left Sidebar', 'spalab' ),
      'dependency'  => array( 'page-layout', 'any', 'with-left-sidebar,with-both-sidebar' ),
    ),
    array(
      'id'        => 'widget-area-left',
      'type'      => 'select',
      'title'     => esc_html__('Choose Left Widget Areas', 'spalab' ),
      'class'     => 'chosen',
      'options'   => spalab_custom_widgets(),
      'attributes'  => array( 
        'multiple'  => 'multiple',
        'data-placeholder' => esc_html__('Select Left Widget Areas','spalab'),
        'style' => 'width: 400px;'
      ),
      'dependency'  => array( 'page-layout', 'any', 'with-left-sidebar,with-both-sidebar' ),
    ),
    array(
      'id'          => 'show-standard-sidebar-right',
      'type'        => 'switcher',
      'title'       => esc_html__('Show Standard Right Sidebar', 'spalab' ),
      'dependency'  => array( 'page-layout', 'any', 'with-right-sidebar,with-both-sidebar' ),
    ),
    array(
      'id'        => 'widget-area-right',
      'type'      => 'select',
      'title'     => esc_html__('Choose Right Widget Areas', 'spalab' ),
      'class'     => 'chosen',
      'options'   => spalab_custom_widgets(),
      'attributes'    => array( 
        'multiple' => 'multiple',
        'data-placeholder' => esc_html__('Select Right Widget Areas','spalab'),
        'style' => 'width: 400px;'
      ),
      'dependency'  => array( 'page-layout', 'any', 'with-right-sidebar,with-both-sidebar' ),
    )
  )
);

// -----------------------------------------
// Meta Breadcrumb Section
// -----------------------------------------
$meta_breadcrumb_section = array(
  'name'  => 'breadcrumb_section',
  'title' => esc_html__('Breadcrumb', 'spalab'),
  'icon'  => 'fa fa-arrows-h',
  'fields' =>  array(
    array(
      'id'      => 'enable-sub-title',
      'type'    => 'switcher',
      'title'   => esc_html__('Show Breadcrumb', 'spalab' ),
      'default' => true
    ),
    array(
    	'id'                 => 'breadcrumb_position',
	'type'               => 'select',
      'title'              => esc_html__('Position', 'spalab' ),
      'options'            => array(
        'header-top-absolute'    => esc_html__('Behind the Header','spalab'),
        'header-top-relative' 	   => esc_html__('Default','spalab'),
		),
		'default'            => 'header-top-relative',	
      'dependency'         => array( 'enable-sub-title', '==', 'true' ),
    ),    
    array(
      'id'    => 'breadcrumb_background',
      'type'  => 'background',
      'title' => esc_html__('Background', 'spalab' ),
      'dependency'   => array( 'enable-sub-title', '==', 'true' ),
    ),
  )
);

// -----------------------------------------
// Meta Slider Section
// -----------------------------------------
$meta_slider_section = array(
  'name'  => 'slider_section',
  'title' => esc_html__('Slider', 'spalab'),
  'icon'  => 'fa fa-slideshare',
  'fields' =>  array(
    array(
      'id'           => 'slider-notice',
      'type'         => 'notice',
      'class'        => 'danger',
      'content'      => esc_html__('Slider tab works only if breadcrumb disabled.','spalab'),
      'class'        => 'margin-30 cs-danger',
      'dependency'   => array( 'enable-sub-title', '==', 'true' ),
    ),

    array(
      'id'           => 'show_slider',
      'type'         => 'switcher',
      'title'        => esc_html__('Show Slider', 'spalab' ),
      'dependency'   => array( 'enable-sub-title', '==', 'false' ),
    ),
    array(
    	'id'                 => 'slider_position',
	'type'               => 'select',
	'title'              => esc_html__('Position', 'spalab' ),
	'options'            => array(
		'header-top-relative'     => esc_html__('Top Header Relative','spalab'),
		'header-top-absolute'    => esc_html__('Top Header Absolute','spalab'),
		'bottom-header' 	   => esc_html__('Bottom Header','spalab'),
	),
	'default'            => 'bottom-header',
	'dependency'         => array( 'enable-sub-title|show_slider', '==|==', 'false|true' ),
   ),
   array(
      'id'                 => 'slider_type',
      'type'               => 'select',
      'title'              => esc_html__('Slider', 'spalab' ),
      'options'            => array(
        ''                 => esc_html__('Select a slider','spalab'),
        'layerslider'      => esc_html__('Layer slider','spalab'),
        'revolutionslider' => esc_html__('Revolution slider','spalab'),
        'customslider'     => esc_html__('Custom Slider Shortcode','spalab'),
      ),
      'validate' => 'required',
      'dependency'         => array( 'enable-sub-title|show_slider', '==|==', 'false|true' ),
    ),

    array(
      'id'          => 'layerslider_id',
      'type'        => 'select',
      'title'       => esc_html__('Layer Slider', 'spalab' ),
      'options'     => spalab_layersliders(),
      'validate'    => 'required',
      'dependency'  => array( 'enable-sub-title|show_slider|slider_type', '==|==|==', 'false|true|layerslider' )
    ),

    array(
      'id'          => 'revolutionslider_id',
      'type'        => 'select',
      'title'       => esc_html__('Revolution Slider', 'spalab' ),
      'options'     => spalab_revolutionsliders(),
      'validate'    => 'required',
      'dependency'  => array( 'enable-sub-title|show_slider|slider_type', '==|==|==', 'false|true|revolutionslider' )
    ),

    array(
      'id'          => 'customslider_sc',
      'type'        => 'textarea',
      'title'       => esc_html__('Custom Slider Code', 'spalab' ),
      'validate'    => 'required',
      'dependency'  => array( 'enable-sub-title|show_slider|slider_type', '==|==|==', 'false|true|customslider' )
    ),
  )  
);

// -----------------------------------------
// Blog Template Section
// -----------------------------------------
$blog_template_section = array(
  'name'  => 'blog_template_section',
  'title' => esc_html__('Blog Template', 'spalab'),
  'icon'  => 'fa fa-files-o',
  'fields' =>  array(
    array(
      'id'           => 'blog-tpl-notice',
      'type'         => 'notice',
      'class'        => 'success',
      'content'      => esc_html__('Blog Tab Works only if page template set to Blog Template in Page Attributes','spalab'),
      'class'        => 'margin-30 cs-success',      
    ),
    array(
      'id'                     => 'blog-post-layout',
      'type'                   => 'image_select',
      'title'                  => esc_html__('Post Layout', 'spalab' ),
      'options'                => array(
          'one-column'         => SPALAB_THEME_URI . '/cs-framework-override/images/one-column.png',
          'one-half-column'    => SPALAB_THEME_URI . '/cs-framework-override/images/one-half-column.png',
          'one-third-column'   => SPALAB_THEME_URI . '/cs-framework-override/images/one-third-column.png',
		  '1-2-2'			   => SPALAB_THEME_URI . '/cs-framework-override/images/1-2-2.png',
		  '1-2-2-1-2-2' 	   => SPALAB_THEME_URI . '/cs-framework-override/images/1-2-2-1-2-2.png',
		  '1-3-3-3'			   => SPALAB_THEME_URI . '/cs-framework-override/images/1-3-3-3.png',
		  '1-3-3-3-1' 		   => SPALAB_THEME_URI . '/cs-framework-override/images/1-3-3-3-1.png',
      ),
      'default'                => 'one-half-column'
    ),
    array(
      'id'                     => 'blog-post-style',
      'type'                   => 'select',
      'title'                  => esc_html__('Post Style', 'spalab' ),
      'options'                => array(
        'blog-default-style' => esc_html__('Default','spalab'),
        'entry-date-left'    => esc_html__('Date Left','spalab'),
		'entry-date-left outer-frame-border'      	=> esc_html__('Date Left Modern', 'spalab'),
        'entry-date-author-left' => esc_html__('Date and Author Left','spalab'),
		'blog-modern-style'      => esc_html__('Modern', 'spalab'),
		'bordered'      		 => esc_html__('Bordered', 'spalab'),
		'classic'      			 => esc_html__('Classic', 'spalab'),
		'entry-overlay-style' 	 => esc_html__('Trendy', 'spalab'),
		'overlap' 				 => esc_html__('Overlap', 'spalab'),
		'entry-center-align'	 => esc_html__('Stripe', 'spalab'),
		'entry-fashion-style'	 => esc_html__('Fashion', 'spalab'),
		'entry-minimal-bordered' => esc_html__('Minimal Bordered', 'spalab'),
        'blog-medium-style'  	 => esc_html__('Medium','spalab'),
        'blog-medium-style dt-blog-medium-highlight' => esc_html__('Medium Highlight','spalab'),
        'blog-medium-style dt-blog-medium-highlight dt-sc-skin-highlight' => esc_html__('Medium Skin Highlight','spalab')
      ),
	  'default'                => 'entry-date-author-left'
    ),
    array(
      'id'      => 'enable-blog-readmore',
      'type'    => 'switcher',
      'title'   => esc_html__('Read More', 'spalab' ),
      'default' => true
    ),
    array(
      'id'           => 'blog-readmore',
      'type'         => 'textarea',
      'title'        => esc_html__('Read More Shortcode', 'spalab' ),
      'default'      => '[dt_sc_button title="Read More" style="filled" icon_type="fontawesome" iconalign="icon-right with-icon" iconclass="fa fa-long-arrow-right" class="type1" /]',
      'dependency'   => array( 'enable-blog-readmore', '==', 'true' ),
    ),
    array(
      'id'      => 'blog-post-excerpt',
      'type'    => 'switcher',
      'title'   => esc_html__('Allow Excerpt', 'spalab' ),
      'default' => true
    ),
    array(
      'id'           => 'blog-post-excerpt-length',
      'type'         => 'number',
      'title'        => esc_html__('Excerpt Length', 'spalab' ),
      'default'      => '45',
      'dependency'   => array( 'blog-post-excerpt', '==', 'true' ),
    ),
    array(
      'id'           => 'blog-post-per-page',
      'type'         => 'number',
      'title'        => esc_html__('Post Per Page', 'spalab' ),
      'default'      => '-1',      
    ),
    array(
      'id'             => 'blog-post-cats',
      'type'           => 'select',
      'title'          => esc_html__('Categories','spalab'),
      'options'        => 'categories',
      'default_option' => esc_html__('Select a categories','spalab'),
      'class'              => 'chosen',
      'attributes'         => array(
        'multiple'         => 'only-key',
        'style'            => 'width: 200px;'
      ),
      'info'           => esc_html__('Select categories to exclude from your blog page.','spalab'),
    ),
    array(
      'id'      => 'show-postformat-info',
      'type'    => 'switcher',
      'title'   => esc_html__('Show Post Format Info', 'spalab' ),
      'default' => true
    ),
    array(
      'id'      => 'show-author-info',
      'type'    => 'switcher',
      'title'   => esc_html__('Show Post Author Info', 'spalab' ),
      'default' => true,
    ),
    array(
      'id'      => 'show-date-info',
      'type'    => 'switcher',
      'title'   => esc_html__('Show Post Date Info', 'spalab' ),
      'default' => true
    ),
    array(
      'id'      => 'show-comment-info',
      'type'    => 'switcher',
      'title'   => esc_html__('Show Post Comment Info', 'spalab' ),
      'default' => true
    ),
    array(
      'id'      => 'show-category-info',
      'type'    => 'switcher',
      'title'   => esc_html__('Show Post Category Info', 'spalab' ),
      'default' => true
    ),
    array(
      'id'      => 'show-tag-info',
      'type'    => 'switcher',
      'title'   => esc_html__('Show Post Tag Info', 'spalab' ),
      'default' => true
    )    
  )
);

// -----------------------------------------
// Portfolio Template Section
// -----------------------------------------
$portfolio_template_section = array(
  'name'  => 'portfolio_template_section',
  'title' => esc_html__('Portfolio Template', 'spalab'),
  'icon'  => 'fa fa-picture-o',
  'fields' =>  array(

    array(
      'id'           => 'portfolio-tpl-notice',
      'type'         => 'notice',
      'class'        => 'success',
      'content'      => esc_html__('Portfolio Tab Works only if page template set to Portfolio Template in Page Attributes','spalab'),
      'class'        => 'margin-30 cs-success',      
    ),

    array(
      'id'                     => 'portfolio-post-layout',
      'type'                   => 'image_select',
      'title'                  => esc_html__('Post Layout', 'spalab' ),
      'options'                => array(
	  	  'one-column'    	   => SPALAB_THEME_URI . '/cs-framework-override/images/one-column.png',
          'one-half-column'    => SPALAB_THEME_URI . '/cs-framework-override/images/one-half-column.png',
          'one-third-column'   => SPALAB_THEME_URI . '/cs-framework-override/images/one-third-column.png',
          'one-fourth-column'  => SPALAB_THEME_URI . '/cs-framework-override/images/one-fourth-column.png',
      ),
      'default'                => 'one-half-column'
    ),

    array(
      'id'      => 'portfolio-post-style',
      'type'    => 'select',
      'title'   => esc_html__('Post Style', 'spalab' ),
      'options' => array(
        'type1' => esc_html__('Modern Title','spalab'),
        'type2' => esc_html__('Title & Icons Overlay','spalab'),
        'type3' => esc_html__('Title Overlay','spalab'),
        'type4' => esc_html__('Icons Only','spalab'),
        'type5' => esc_html__('Classic','spalab'),
        'type6' => esc_html__('Minimal Icons','spalab'),
        'type7' => esc_html__('Presentation','spalab'),
        'type8' => esc_html__('Girly','spalab'),
        'type9' => esc_html__('Art','spalab'),
		'type10' => esc_html__('Like This','spalab'),
		'type11' => esc_html__('Shape One','spalab'),
		'type12' => esc_html__('Shape Two','spalab'),
		'type13' => esc_html__('Shape Three','spalab'),
		'type14' => esc_html__('Shape Four','spalab'),
      ),
    ),
	
	array(
      'id'      => 'gallery-post-hover-design-type',
      'type'    => 'select',
      'title'   => esc_html__('Like This Hover Post Style', 'spalab' ),
      'options' => array(
        'design1' => esc_html__('Type 1','spalab'),
        'design2' => esc_html__('Type 2','spalab'),
        'design3' => esc_html__('Type 3','spalab'),
        'design4' => esc_html__('Type 4','spalab'),
    	),
	  'dependency'  => array('portfolio-post-style', 'any', 'type10' ),
	),

    array(
      'id'      => 'portfolio-grid-space',
      'type'    => 'switcher',
      'title'   => esc_html__('Allow Grid Space', 'spalab' ),
      'default' => true,
      'info'    => esc_html__('YES! to allow grid space in between gallery item','spalab')
    ),

    array(
      'id'      => 'filter',
      'type'    => 'switcher',
      'title'   => esc_html__('Allow Filters', 'spalab' ),
      'default' => true,
      'info'    => esc_html__('YES! to allow filter options for gallery items','spalab')
    ),

    array(
      'id'           => 'portfolio-post-per-page',
      'type'         => 'number',
      'title'        => esc_html__('Post Per Page', 'spalab' ),
      'default'      => '-1',      
    ),

    array(
      'id'             => 'portfolio-categories',
      'type'           => 'select',
      'title'          => esc_html__('Categories','spalab'),
      'options'        => 'categories',
      'class'          => 'chosen',
      'query_args'     => array(
        'type'         => 'dt_portfolios',
        'taxonomy'     => 'portfolio_entries',
        'orderby'      => 'post_date',
        'order'        => 'DESC',
      ),
      'attributes'         => array(
        'data-placeholder' => esc_html__('Select a categories','spalab'),
        'multiple'         => 'only-key',
        'style'            => 'width: 200px;'
      ),
      'info'           => esc_html__('Select categories to show in gallery items.','spalab'),
    ),   
  )
);


// -----------------------------------------
// Catalog Template Section
// -----------------------------------------
$catalog_template_section = array(
  'name'  => 'catalog_template_section',
  'title' => esc_html__('Catalog Template', 'spalab'),
  'icon'  => 'fa fa-picture-o',
  'fields' =>  array(

    array(
      'id'           => 'catalog-tpl-notice',
      'type'         => 'notice',
      'class'        => 'success',
      'content'      => esc_html__('Catalog Tab Works only if page template set to Catalog Template in Page Attributes','spalab'),
      'class'        => 'margin-30 cs-success',      
    ),

    array(
      'id'                     => 'catalog-post-layout',
      'type'                   => 'image_select',
      'title'                  => esc_html__('Post Layout', 'spalab' ),
      'options'                => array(
            'one-column'           => SPALAB_THEME_URI . '/cs-framework-override/images/one-column.png',
          'one-half-column'    => SPALAB_THEME_URI . '/cs-framework-override/images/one-half-column.png',
      ),
      'default'                => 'one-half-column'
    ),

    array(
      'id'             => 'catalog-categories',
      'type'           => 'select',
      'title'          => esc_html__('Categories','spalab'),
      'options'        => 'categories',
      'class'          => 'chosen',
      'query_args'     => array(
        'type'         => 'dt_catalog',
        'taxonomy'     => 'catalog_entries',
        'orderby'      => 'post_date',
        'order'        => 'DESC',
      ),
      'attributes'         => array(
        'data-placeholder' => esc_html__('Select a categories','spalab'),
        'multiple'         => 'only-key',
        'style'            => 'width: 200px;'
      ),
      'info'           => esc_html__('Select categories to show in catalog items.','spalab'),
    ),  
  )
);

// ===============================================================================================
// -----------------------------------------------------------------------------------------------
// METABOX OPTIONS
// -----------------------------------------------------------------------------------------------
// ===============================================================================================
$options = array();

// -----------------------------------------
// Page Metabox Options                    -
// -----------------------------------------
array_push( $meta_layout_section['fields'], array(
  'id'        => 'enable-sticky-sidebar',
  'type'      => 'switcher',
  'title'     => esc_html__('Enable Sticky Sidebar', 'spalab' ),
  'dependency'  => array( 'page-layout', 'any', 'with-left-sidebar,with-right-sidebar,with-both-sidebar' )
) );

$options[] = array(
	'id'        => '_tpl_default_settings',
    'title'     => esc_html__('Page Settings','spalab'),
    'post_type' => 'page',
    'context'   => 'normal',
    'priority'  => 'high',
    'sections'  => array(
		$meta_layout_section,
		$meta_breadcrumb_section,
		$meta_slider_section,
		$blog_template_section,
		$portfolio_template_section,
		$catalog_template_section,
		array(
		  'name'  => 'sidenav_template_section',
		  'title' => esc_html__('Side Navigation Template', 'spalab'),
		  'icon'  => 'fa fa-th-list',
		  'fields' =>  array(

			array(
			  'id'           => 'sidenav-tpl-notice',
			  'type'         => 'notice',
			  'class'        => 'success',
			  'content'      => esc_html__('Side Navigation Tab Works only if page template set to Side Navigation Template in Page Attributes','spalab'),
			  'class'        => 'margin-30 cs-success',      
			),

			array(
			  'id'     		 => 'sidenav-style',
			  'type'    	 => 'select',
			  'title'   	 => esc_html__('Side Navigation Style', 'spalab' ),
			  'options'    => array(
				   'type1' => esc_html__('Type1','spalab'),
				   'type2' => esc_html__('Type2','spalab'),
				   'type3' => esc_html__('Type3','spalab'),
				   'type4' => esc_html__('Type4','spalab'),
				   'type5' => esc_html__('Type5','spalab'),
				   'type6' => esc_html__('Type6','spalab'),
				   'type7' => esc_html__('Type7','spalab'),
				   'type8' => esc_html__('Type8','spalab'),
				   'type9' => esc_html__('Type9','spalab'),
				   'type10' => esc_html__('Type10','spalab')
			  ),
			),

			array(
			  'id'    		 => 'sidenav-align',
			  'type'    	 => 'switcher',
			  'title'   	 => esc_html__('Align Right', 'spalab' ),
			  'info'    	 => esc_html__('YES! to align right of side navigation.','spalab')
			),

			array(
			  'id'    		 => 'sidenav-sticky',
			  'type'    	 => 'switcher',
			  'title'   	 => esc_html__('Sticky Side Navigation', 'spalab' ),
			  'info'    	 => esc_html__('YES! to sticky side navigation content.','spalab')
			),

			array(
			  'id'    		 => 'enable-sidenav-content',
			  'type'    	 => 'switcher',
			  'title'   	 => esc_html__('Show Content', 'spalab' ),
			  'info'    	 => esc_html__('YES! to show content in below side navigation.','spalab')
			),

			array(
			  'id'	    	 => 'sidenav-content',
			  'type'	     => 'textarea',
			  'title'  		 => esc_html__('Side Navigation Content', 'spalab' ),
			  'info'    	 => esc_html__('Paste any shortcode content here','spalab'),
			  'attributes' 	 => array(
				  'rows'     => 6,
			  ),
			),

		  )
		),
    )
);

// -----------------------------------------
// Post Metabox Options                    -
// -----------------------------------------
$post_meta_layout_section = $meta_layout_section;
$fields = $post_meta_layout_section['fields'];

	$fields[0]['title'] =  esc_html__('Post Layout', 'spalab' );
	unset( $fields[0]['options']['with-both-sidebar'] );
	unset( $fields[0]['info'] );
	unset( $fields[0]['options']['fullwidth'] );
	unset( $fields[5] );
	unset( $post_meta_layout_section['fields'] );
	$post_meta_layout_section['fields']  = $fields;  

	$post_format_section = array(
		'name'  => 'post_format_data_section',
		'title' => esc_html__('Post Format', 'spalab'),
		'icon'  => 'fa fa-cog',
		'fields' =>  array(

			array(
				'id'      => 'show-featured-image',
				'type'    => 'switcher',
				'title'   => esc_html__('Show Featured Image', 'spalab' ),
				'default' => true,
				'info'    => esc_html__('YES! to show featured image','spalab')
			),

			array(
				'id'           => 'single-post-style',
				'type'         => 'select',
				'title'        => esc_html__('Post Style', 'spalab'),
				'options'      => array(
				  'standard'      		=> esc_html__('Standard', 'spalab'),
				  'info-within-image'   => esc_html__('Info WithIn Image', 'spalab'),
				  'info-bottom-image'   => esc_html__('Info Over Image Bottom Left', 'spalab'),
				  'info-vertical-image' => esc_html__('Info Over Image Vertically Center', 'spalab'),
				  'info-above-image'    => esc_html__('Info Above Image', 'spalab'),
				  'single-flat' 		=> esc_html__('Flat', 'spalab'),
				  'left-date' 		 	=> esc_html__('Left Date', 'spalab')
				),
				'class'        => 'chosen',
				'default'      => 'left-date',
				'info'         => esc_html__('Choose post style to display single post.', 'spalab')
			),

			array(
				'id' => 'post-format-type',
				'title'   => esc_html__('Type', 'spalab' ),
				'type' => 'select',
				'default' => 'standard',
				'options' => array(
					'standard'  => esc_html__('Standard', 'spalab'),
					'status'	=> esc_html__('Status','spalab'),
					'quote'		=> esc_html__('Quote','spalab'),
					'gallery'	=> esc_html__('Gallery','spalab'),
					'image'		=> esc_html__('Image','spalab'),
					'video'		=> esc_html__('Video','spalab'),
					'audio'		=> esc_html__('Audio','spalab'),
					'link'		=> esc_html__('Link','spalab'),
					'aside'		=> esc_html__('Aside','spalab'),
					'chat'		=> esc_html__('Chat','spalab')
				)
			),

			array(
				'id' 	  => 'post-gallery-items',
				'type'	  => 'gallery',
				'title'   => esc_html__('Add Images', 'spalab' ),
				'add_title'   => esc_html__('Add Images', 'spalab' ),
				'edit_title'  => esc_html__('Edit Images', 'spalab' ),
				'clear_title' => esc_html__('Remove Images', 'spalab' ),
				'dependency' => array( 'post-format-type', '==', 'gallery' ),
			),

			array(
				'id' 	  => 'media-type',
				'type'	  => 'select',
				'title'   => esc_html__('Select Type', 'spalab' ),
				'dependency' => array( 'post-format-type', 'any', 'video,audio' ),
		      	'options'	=> array(
					'oembed' => esc_html__('Oembed','spalab'),
					'self' => esc_html__('Self Hosted','spalab'),
				)
			),

			array(
				'id' 	  => 'media-url',
				'type'	  => 'textarea',
				'title'   => esc_html__('Media URL', 'spalab' ),
				'dependency' => array( 'post-format-type', 'any', 'video,audio' ),
			),
		)
	);

	$options[] = array(
		'id'        => '_dt_post_settings',
		'title'     => esc_html__('Post Settings','spalab'),
		'post_type' => 'post',
		'context'   => 'normal',
		'priority'  => 'high',
		'sections'  => array(
			$post_meta_layout_section,
			$meta_breadcrumb_section,
			$post_format_section			
		)
	);

// -----------------------------------------
// Tribe Events Post Metabox Options
// -----------------------------------------
  array_push( $post_meta_layout_section['fields'], array(
    'id' => 'event-post-style',
    'title'   => esc_html__('Post Style', 'spalab' ),
    'type' => 'select',
    'default' => 'type1',
    'options' => array(
      'type1'  => esc_html__('Classic', 'spalab'),
      'type2'  => esc_html__('Full Width','spalab'),
      'type3'  => esc_html__('Minimal Tab','spalab'),
      'type4'  => esc_html__('Clean','spalab'),
      'type5'  => esc_html__('Modern','spalab'),
    ),
	'class'    => 'chosen',
	'info'     => esc_html__('Your event post page show at most selected style.', 'spalab')
  ) );

  $options[] = array(
    'id'        => '_custom_settings',
    'title'     => esc_html__('Settings','spalab'),
    'post_type' => 'tribe_events',
    'context'   => 'normal',
    'priority'  => 'high',
    'sections'  => array(
      $post_meta_layout_section,
      $meta_breadcrumb_section
    )
  );


// -----------------------------------------
// Header And Footer Options Metabox
// -----------------------------------------
$post_types = apply_filters( 'spalab_header_footer_default_cpt' , array ( 'post', 'page' )  );
$options[] = array(
	'id'	=> '_dt_custom_settings',
	'title'	=> esc_html__('Header & Footer','spalab'),
	'post_type' => $post_types,
	'priority'  => 'high',
	'context'   => 'side', 
	'sections'  => array(
	
		# Header Settings
		array(
			'name'  => 'header_section',
			'title' => esc_html__('Header', 'spalab'),
			'icon'  => 'fa fa-angle-double-right',
			'fields' =>  array(
			
				# Header Show / Hide
				array(
					'id'		=> 'show-header',
					'type'		=> 'switcher',
					'title'		=> esc_html__('Show Header', 'spalab'),
					'default'	=>  true,
				),
				
				# Header
				array(
					'id'  		 => 'header',
					'type'  	 => 'select',
					'title' 	 => esc_html__('Choose Header', 'spalab'),
					'class'		 => 'chosen',
					'options'	 => 'posts',
					'query_args' => array(
						'post_type'	 => 'dt_headers',
						'orderby'	 => 'ID',
						'order'		 => 'ASC',
						'posts_per_page' => -1,
					),
					'default_option' => esc_attr__('Select Header', 'spalab'),
					'attributes' => array( 'style'	=> 'width:50%' ),
					'info'		 => esc_html__('Select custom header for this page.','spalab'),
					'dependency'	=> array( 'show-header', '==', 'true' )
				),							
			)			
		),
		# Header Settings

		# Footer Settings
		array(
			'name'  => 'footer_settings',
			'title' => esc_html__('Footer', 'spalab'),
			'icon'  => 'fa fa-angle-double-right',
			'fields' =>  array(
			
				# Footer Show / Hide
				array(
					'id'		=> 'show-footer',
					'type'		=> 'switcher',
					'title'		=> esc_html__('Show Footer', 'spalab'),
					'default'	=>  true,
				),
				
				# Footer
		        array(
					'id'         => 'footer',
					'type'       => 'select',
					'title'      => esc_html__('Choose Footer', 'spalab'),
					'class'      => 'chosen',
					'options'    => 'posts',
					'query_args' => array(
						'post_type'  => 'dt_footers',
						'orderby'    => 'ID',
						'order'      => 'ASC',
						'posts_per_page' => -1,
					),
					'default_option' => esc_attr__('Select Footer', 'spalab'),
					'attributes' => array( 'style'  => 'width:50%' ),
					'info'       => esc_html__('Select custom footer for this page.','spalab'),
					'dependency'    => array( 'show-footer', '==', 'true' )
				),			
			)			
		),
		# Footer Settings
		
	)	
);



	
CSFramework_Metabox::instance( $options );